==> q3-ui-rest-0.7.0.tgz: package/lib/rest.stories.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _react2 = require("@storybook/react");

var _rest = _interopRequireDefault(require("q3-ui-test-utils/lib/rest"));

var _src = _interopRequireDefault(require("../packages/q3-ui-forms/src"));

var _lib = _interopRequireDefault(require("../lib"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const StatefulGet = () => {
  const rest = (0, _lib.default)({
    url: '/rest',
    runOnInit: true,
    key: 'name',
    pluralized: 'names'
  });
  return _react.default.createElement(_react.default.Fragment, null, _react.default.createElement("button", {
    type: "button",
    onClick: () => rest.get()
  }, "Click to reload data:", ' ', rest.loading ? 'Loading ....' : null), _react.default.createElement("code", null, JSON.stringify(rest.names)));
};

const StatefulPatch = () => {
  const rest = (0, _lib.default)({
    url: '/rest',
    key: 'name',
    pluralized: 'names'
  });
  console.log(rest.patch);
  return _react.default.createElement(_react.default.Fragment, null, _react.default.createElement("button", {
    type: "button",
    onClick: rest.patch(1)
  }, "Click to patch (last updated:)", rest.loading ? 'Loading ....' : null));
};

(0, _react2.storiesOf)('REST utils', module).add('304 cache', () => {
  const definePermission = m => {
    m.onGet('/rest').replyOnce(200, {
      names: [{
        name: 'Albert'
      }, {
        name: 'John'
      }, {
        name: 'Greg'
      }, {
        name: 'Mary'
      }]
    }, {
      ETag: '275-G6p5Qbvjb7eETPVAmGeJb4Xw6+c'
    }).onGet('/rest').reply(304, {}, {
      ETag: '275-G6p5Qbvjb7eETPVAmGeJb4Xw6+c'
    });
  };

  return _react.default.createElement(_src.default, null, _react.default.createElement(_rest.default, {
    define: definePermission
  }, _react.default.createElement(StatefulGet, null)));
}).add('412 race conditions', () => {
  const definePermission = m => {
    m.onPatch('/rest/1').reply(412, {});
  };

  return _react.default.createElement(_src.default, null, _react.default.createElement(_rest.default, {
    define: definePermission
  }, _react.default.createElement(StatefulPatch, null)));
});

==> q3-ui-rest-1.16.7.tgz: package/lib/rest.stories.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _react2 = require("@storybook/react");

var _rest = _interopRequireDefault(require("q3-ui-test-utils/lib/rest"));

var _q3UiForms = _interopRequireDefault(require("q3-ui-forms"));

var _ = _interopRequireDefault(require("."));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const StatefulGet = () => {
  const rest = (0, _.default)({
    url: '/rest',
    runOnInit: true,
    key: 'name',
    pluralized: 'names'
  });
  return _react.default.createElement(_react.default.Fragment, null, _react.default.createElement("button", {
    type: "button",
    onClick: () => rest.get()
  }, "Click to reload data:", ' ', rest.loading ? 'Loading ....' : null), _react.default.createElement("code", null, JSON.stringify(rest.names)));
};

const StatefulPatch = () => {
  const rest = (0, _.default)({
    url: '/rest',
    key: 'name',
    pluralized: 'names'
  });
  console.log(rest.patch);
  return _react.default.createElement(_react.default.Fragment, null, _react.default.createElement("button", {
    type: "button",
    onClick: rest.patch(1)
  }, "Click to patch (last updated:)", rest.loading ? 'Loading ....' : null));
};

(0, _react2.storiesOf)('REST utils', module).add('304 cache', () => {
  const definePermission = m => {
    m.onGet('/rest').replyOnce(200, {
      names: [{
        name: 'Albert'
      }, {
        name: 'John'
      }, {
        name: 'Greg'
      }, {
        name: 'Mary'
      }]
    }, {
      ETag: '275-G6p5Qbvjb7eETPVAmGeJb4Xw6+c'
    }).onGet('/rest').reply(304, {}, {
      ETag: '275-G6p5Qbvjb7eETPVAmGeJb4Xw6+c'
    });
  };

  return _react.default.createElement(_q3UiForms.default, null, _react.default.createElement(_rest.default, {
    define: definePermission
  }, _react.default.createElement(StatefulGet, null)));
}).add('412 race conditions', () => {
  const definePermission = m => {
    m.onPatch('/rest/1').reply(412, {});
  };

  return _react.default.createElement(_q3UiForms.default, null, _react.default.createElement(_rest.default, {
    define: definePermission
  }, _react.default.createElement(StatefulPatch, null)));
});
